Class: Aws::States::Types::CreateActivityInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::States::Types::CreateActivityInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-states/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#encryption_configuration ⇒ Types::EncryptionConfiguration
Settings to configure server-side encryption.
-
#name ⇒ String
The name of the activity to create.
-
#tags ⇒ Array<Types::Tag>
The list of tags to add to a resource.
Instance Attribute Details
#encryption_configuration ⇒ Types::EncryptionConfiguration
Settings to configure server-side encryption.
369 370 371 372 373 374 375 |
# File 'lib/aws-sdk-states/types.rb', line 369 class CreateActivityInput < Struct.new( :name, :tags, :encryption_configuration) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the activity to create. This name must be unique for your Amazon Web Services account and region.
A name must not contain:
-
white space
-
brackets
< > { } [ ] -
wildcard characters
? * -
special characters
" # % \ ^ | ~ ` $ & , ; : / -
control characters (
U+0000-001F,U+007F-009F,U+FFFE-FFFF) -
surrogates (
U+D800-DFFF) -
invalid characters (
U+10FFFF)
To enable logging with CloudWatch Logs, the name should only contain 0-9, A-Z, a-z, - and _.
369 370 371 372 373 374 375 |
# File 'lib/aws-sdk-states/types.rb', line 369 class CreateActivityInput < Struct.new( :name, :tags, :encryption_configuration) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
The list of tags to add to a resource.
An array of key-value pairs. For more information, see Using Cost Allocation Tags in the Amazon Web Services Billing and Cost Management User Guide, and Controlling Access Using IAM Tags.
Tags may only contain Unicode letters, digits, white space, or these
symbols: _ . : / = + - @.
369 370 371 372 373 374 375 |
# File 'lib/aws-sdk-states/types.rb', line 369 class CreateActivityInput < Struct.new( :name, :tags, :encryption_configuration) SENSITIVE = [] include Aws::Structure end |