Class: Aws::States::Types::DescribeStateMachineForExecutionInput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-states/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#execution_arnString

The Amazon Resource Name (ARN) of the execution you want state machine information for.

Returns:

  • (String)


1088
1089
1090
1091
1092
1093
# File 'lib/aws-sdk-states/types.rb', line 1088

class DescribeStateMachineForExecutionInput < Struct.new(
  :execution_arn,
  :included_data)
  SENSITIVE = []
  include Aws::Structure
end

#included_dataString

If your state machine definition is encrypted with a KMS key, callers must have kms:Decrypt permission to decrypt the definition. Alternatively, you can call the API with includedData = METADATA_ONLY to get a successful response without the encrypted definition.

Returns:

  • (String)


1088
1089
1090
1091
1092
1093
# File 'lib/aws-sdk-states/types.rb', line 1088

class DescribeStateMachineForExecutionInput < Struct.new(
  :execution_arn,
  :included_data)
  SENSITIVE = []
  include Aws::Structure
end