Class: Aws::States::Types::DescribeStateMachineForExecutionOutput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-states/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:definition, :variable_references]

Instance Attribute Summary collapse

Instance Attribute Details

#definitionString

The Amazon States Language definition of the state machine. See Amazon States Language.

Returns:

  • (String)


1168
1169
1170
1171
1172
1173
1174
1175
1176
1177
1178
1179
1180
1181
1182
1183
# File 'lib/aws-sdk-states/types.rb', line 1168

class DescribeStateMachineForExecutionOutput < Struct.new(
  :state_machine_arn,
  :name,
  :definition,
  :role_arn,
  :update_date,
  :logging_configuration,
  :tracing_configuration,
  :map_run_arn,
  :label,
  :revision_id,
  :encryption_configuration,
  :variable_references)
  SENSITIVE = [:definition, :variable_references]
  include Aws::Structure
end

#encryption_configurationTypes::EncryptionConfiguration

Settings to configure server-side encryption.



1168
1169
1170
1171
1172
1173
1174
1175
1176
1177
1178
1179
1180
1181
1182
1183
# File 'lib/aws-sdk-states/types.rb', line 1168

class DescribeStateMachineForExecutionOutput < Struct.new(
  :state_machine_arn,
  :name,
  :definition,
  :role_arn,
  :update_date,
  :logging_configuration,
  :tracing_configuration,
  :map_run_arn,
  :label,
  :revision_id,
  :encryption_configuration,
  :variable_references)
  SENSITIVE = [:definition, :variable_references]
  include Aws::Structure
end

#labelString

A user-defined or an auto-generated string that identifies a Map state. This field is returned only if the executionArn is a child workflow execution that was started by a Distributed Map state.

Returns:

  • (String)


1168
1169
1170
1171
1172
1173
1174
1175
1176
1177
1178
1179
1180
1181
1182
1183
# File 'lib/aws-sdk-states/types.rb', line 1168

class DescribeStateMachineForExecutionOutput < Struct.new(
  :state_machine_arn,
  :name,
  :definition,
  :role_arn,
  :update_date,
  :logging_configuration,
  :tracing_configuration,
  :map_run_arn,
  :label,
  :revision_id,
  :encryption_configuration,
  :variable_references)
  SENSITIVE = [:definition, :variable_references]
  include Aws::Structure
end

#logging_configurationTypes::LoggingConfiguration

The LoggingConfiguration data type is used to set CloudWatch Logs options.



1168
1169
1170
1171
1172
1173
1174
1175
1176
1177
1178
1179
1180
1181
1182
1183
# File 'lib/aws-sdk-states/types.rb', line 1168

class DescribeStateMachineForExecutionOutput < Struct.new(
  :state_machine_arn,
  :name,
  :definition,
  :role_arn,
  :update_date,
  :logging_configuration,
  :tracing_configuration,
  :map_run_arn,
  :label,
  :revision_id,
  :encryption_configuration,
  :variable_references)
  SENSITIVE = [:definition, :variable_references]
  include Aws::Structure
end

#map_run_arnString

The Amazon Resource Name (ARN) of the Map Run that started the child workflow execution. This field is returned only if the executionArn is a child workflow execution that was started by a Distributed Map state.

Returns:

  • (String)


1168
1169
1170
1171
1172
1173
1174
1175
1176
1177
1178
1179
1180
1181
1182
1183
# File 'lib/aws-sdk-states/types.rb', line 1168

class DescribeStateMachineForExecutionOutput < Struct.new(
  :state_machine_arn,
  :name,
  :definition,
  :role_arn,
  :update_date,
  :logging_configuration,
  :tracing_configuration,
  :map_run_arn,
  :label,
  :revision_id,
  :encryption_configuration,
  :variable_references)
  SENSITIVE = [:definition, :variable_references]
  include Aws::Structure
end

#nameString

The name of the state machine associated with the execution.

Returns:

  • (String)


1168
1169
1170
1171
1172
1173
1174
1175
1176
1177
1178
1179
1180
1181
1182
1183
# File 'lib/aws-sdk-states/types.rb', line 1168

class DescribeStateMachineForExecutionOutput < Struct.new(
  :state_machine_arn,
  :name,
  :definition,
  :role_arn,
  :update_date,
  :logging_configuration,
  :tracing_configuration,
  :map_run_arn,
  :label,
  :revision_id,
  :encryption_configuration,
  :variable_references)
  SENSITIVE = [:definition, :variable_references]
  include Aws::Structure
end

#revision_idString

The revision identifier for the state machine. The first revision ID when you create the state machine is null.

Use the state machine revisionId parameter to compare the revision of a state machine with the configuration of the state machine used for executions without performing a diff of the properties, such as definition and roleArn.

Returns:

  • (String)


1168
1169
1170
1171
1172
1173
1174
1175
1176
1177
1178
1179
1180
1181
1182
1183
# File 'lib/aws-sdk-states/types.rb', line 1168

class DescribeStateMachineForExecutionOutput < Struct.new(
  :state_machine_arn,
  :name,
  :definition,
  :role_arn,
  :update_date,
  :logging_configuration,
  :tracing_configuration,
  :map_run_arn,
  :label,
  :revision_id,
  :encryption_configuration,
  :variable_references)
  SENSITIVE = [:definition, :variable_references]
  include Aws::Structure
end

#role_arnString

The Amazon Resource Name (ARN) of the IAM role of the State Machine for the execution.

Returns:

  • (String)


1168
1169
1170
1171
1172
1173
1174
1175
1176
1177
1178
1179
1180
1181
1182
1183
# File 'lib/aws-sdk-states/types.rb', line 1168

class DescribeStateMachineForExecutionOutput < Struct.new(
  :state_machine_arn,
  :name,
  :definition,
  :role_arn,
  :update_date,
  :logging_configuration,
  :tracing_configuration,
  :map_run_arn,
  :label,
  :revision_id,
  :encryption_configuration,
  :variable_references)
  SENSITIVE = [:definition, :variable_references]
  include Aws::Structure
end

#state_machine_arnString

The Amazon Resource Name (ARN) of the state machine associated with the execution.

Returns:

  • (String)


1168
1169
1170
1171
1172
1173
1174
1175
1176
1177
1178
1179
1180
1181
1182
1183
# File 'lib/aws-sdk-states/types.rb', line 1168

class DescribeStateMachineForExecutionOutput < Struct.new(
  :state_machine_arn,
  :name,
  :definition,
  :role_arn,
  :update_date,
  :logging_configuration,
  :tracing_configuration,
  :map_run_arn,
  :label,
  :revision_id,
  :encryption_configuration,
  :variable_references)
  SENSITIVE = [:definition, :variable_references]
  include Aws::Structure
end

#tracing_configurationTypes::TracingConfiguration

Selects whether X-Ray tracing is enabled.



1168
1169
1170
1171
1172
1173
1174
1175
1176
1177
1178
1179
1180
1181
1182
1183
# File 'lib/aws-sdk-states/types.rb', line 1168

class DescribeStateMachineForExecutionOutput < Struct.new(
  :state_machine_arn,
  :name,
  :definition,
  :role_arn,
  :update_date,
  :logging_configuration,
  :tracing_configuration,
  :map_run_arn,
  :label,
  :revision_id,
  :encryption_configuration,
  :variable_references)
  SENSITIVE = [:definition, :variable_references]
  include Aws::Structure
end

#update_dateTime

The date and time the state machine associated with an execution was updated. For a newly created state machine, this is the creation date.

Returns:

  • (Time)


1168
1169
1170
1171
1172
1173
1174
1175
1176
1177
1178
1179
1180
1181
1182
1183
# File 'lib/aws-sdk-states/types.rb', line 1168

class DescribeStateMachineForExecutionOutput < Struct.new(
  :state_machine_arn,
  :name,
  :definition,
  :role_arn,
  :update_date,
  :logging_configuration,
  :tracing_configuration,
  :map_run_arn,
  :label,
  :revision_id,
  :encryption_configuration,
  :variable_references)
  SENSITIVE = [:definition, :variable_references]
  include Aws::Structure
end

#variable_referencesHash<String,Array<String>>

A map of state name to a list of variables referenced by that state. States that do not use variable references will not be shown in the response.

Returns:

  • (Hash<String,Array<String>>)


1168
1169
1170
1171
1172
1173
1174
1175
1176
1177
1178
1179
1180
1181
1182
1183
# File 'lib/aws-sdk-states/types.rb', line 1168

class DescribeStateMachineForExecutionOutput < Struct.new(
  :state_machine_arn,
  :name,
  :definition,
  :role_arn,
  :update_date,
  :logging_configuration,
  :tracing_configuration,
  :map_run_arn,
  :label,
  :revision_id,
  :encryption_configuration,
  :variable_references)
  SENSITIVE = [:definition, :variable_references]
  include Aws::Structure
end