Class: Aws::States::Types::DescribeStateMachineOutput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-states/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:definition, :description, :variable_references]

Instance Attribute Summary collapse

Instance Attribute Details

#creation_dateTime

The date the state machine is created.

For a state machine version, creationDate is the date the version was created.

Returns:

  • (Time)


1324
1325
1326
1327
1328
1329
1330
1331
1332
1333
1334
1335
1336
1337
1338
1339
1340
1341
# File 'lib/aws-sdk-states/types.rb', line 1324

class DescribeStateMachineOutput < Struct.new(
  :state_machine_arn,
  :name,
  :status,
  :definition,
  :role_arn,
  :type,
  :creation_date,
  :logging_configuration,
  :tracing_configuration,
  :label,
  :revision_id,
  :description,
  :encryption_configuration,
  :variable_references)
  SENSITIVE = [:definition, :description, :variable_references]
  include Aws::Structure
end

#definitionString

The Amazon States Language definition of the state machine. See Amazon States Language.

If called with includedData = METADATA_ONLY, the returned definition will be {}.

Returns:

  • (String)


1324
1325
1326
1327
1328
1329
1330
1331
1332
1333
1334
1335
1336
1337
1338
1339
1340
1341
# File 'lib/aws-sdk-states/types.rb', line 1324

class DescribeStateMachineOutput < Struct.new(
  :state_machine_arn,
  :name,
  :status,
  :definition,
  :role_arn,
  :type,
  :creation_date,
  :logging_configuration,
  :tracing_configuration,
  :label,
  :revision_id,
  :description,
  :encryption_configuration,
  :variable_references)
  SENSITIVE = [:definition, :description, :variable_references]
  include Aws::Structure
end

#descriptionString

The description of the state machine version.

Returns:

  • (String)


1324
1325
1326
1327
1328
1329
1330
1331
1332
1333
1334
1335
1336
1337
1338
1339
1340
1341
# File 'lib/aws-sdk-states/types.rb', line 1324

class DescribeStateMachineOutput < Struct.new(
  :state_machine_arn,
  :name,
  :status,
  :definition,
  :role_arn,
  :type,
  :creation_date,
  :logging_configuration,
  :tracing_configuration,
  :label,
  :revision_id,
  :description,
  :encryption_configuration,
  :variable_references)
  SENSITIVE = [:definition, :description, :variable_references]
  include Aws::Structure
end

#encryption_configurationTypes::EncryptionConfiguration

Settings to configure server-side encryption.



1324
1325
1326
1327
1328
1329
1330
1331
1332
1333
1334
1335
1336
1337
1338
1339
1340
1341
# File 'lib/aws-sdk-states/types.rb', line 1324

class DescribeStateMachineOutput < Struct.new(
  :state_machine_arn,
  :name,
  :status,
  :definition,
  :role_arn,
  :type,
  :creation_date,
  :logging_configuration,
  :tracing_configuration,
  :label,
  :revision_id,
  :description,
  :encryption_configuration,
  :variable_references)
  SENSITIVE = [:definition, :description, :variable_references]
  include Aws::Structure
end

#labelString

A user-defined or an auto-generated string that identifies a Map state. This parameter is present only if the stateMachineArn specified in input is a qualified state machine ARN.

Returns:

  • (String)


1324
1325
1326
1327
1328
1329
1330
1331
1332
1333
1334
1335
1336
1337
1338
1339
1340
1341
# File 'lib/aws-sdk-states/types.rb', line 1324

class DescribeStateMachineOutput < Struct.new(
  :state_machine_arn,
  :name,
  :status,
  :definition,
  :role_arn,
  :type,
  :creation_date,
  :logging_configuration,
  :tracing_configuration,
  :label,
  :revision_id,
  :description,
  :encryption_configuration,
  :variable_references)
  SENSITIVE = [:definition, :description, :variable_references]
  include Aws::Structure
end

#logging_configurationTypes::LoggingConfiguration

The LoggingConfiguration data type is used to set CloudWatch Logs options.



1324
1325
1326
1327
1328
1329
1330
1331
1332
1333
1334
1335
1336
1337
1338
1339
1340
1341
# File 'lib/aws-sdk-states/types.rb', line 1324

class DescribeStateMachineOutput < Struct.new(
  :state_machine_arn,
  :name,
  :status,
  :definition,
  :role_arn,
  :type,
  :creation_date,
  :logging_configuration,
  :tracing_configuration,
  :label,
  :revision_id,
  :description,
  :encryption_configuration,
  :variable_references)
  SENSITIVE = [:definition, :description, :variable_references]
  include Aws::Structure
end

#nameString

The name of the state machine.

A name must not contain:

  • white space

  • brackets < > { } [ ]

  • wildcard characters ? *

  • special characters " # % \ ^ | ~ ` $ & , ; : /

  • control characters (U+0000-001F, U+007F-009F, U+FFFE-FFFF)

  • surrogates (U+D800-DFFF)

  • invalid characters ( U+10FFFF)

To enable logging with CloudWatch Logs, the name should only contain 0-9, A-Z, a-z, - and _.

Returns:

  • (String)


1324
1325
1326
1327
1328
1329
1330
1331
1332
1333
1334
1335
1336
1337
1338
1339
1340
1341
# File 'lib/aws-sdk-states/types.rb', line 1324

class DescribeStateMachineOutput < Struct.new(
  :state_machine_arn,
  :name,
  :status,
  :definition,
  :role_arn,
  :type,
  :creation_date,
  :logging_configuration,
  :tracing_configuration,
  :label,
  :revision_id,
  :description,
  :encryption_configuration,
  :variable_references)
  SENSITIVE = [:definition, :description, :variable_references]
  include Aws::Structure
end

#revision_idString

The revision identifier for the state machine.

Use the revisionId parameter to compare between versions of a state machine configuration used for executions without performing a diff of the properties, such as definition and roleArn.

Returns:

  • (String)


1324
1325
1326
1327
1328
1329
1330
1331
1332
1333
1334
1335
1336
1337
1338
1339
1340
1341
# File 'lib/aws-sdk-states/types.rb', line 1324

class DescribeStateMachineOutput < Struct.new(
  :state_machine_arn,
  :name,
  :status,
  :definition,
  :role_arn,
  :type,
  :creation_date,
  :logging_configuration,
  :tracing_configuration,
  :label,
  :revision_id,
  :description,
  :encryption_configuration,
  :variable_references)
  SENSITIVE = [:definition, :description, :variable_references]
  include Aws::Structure
end

#role_arnString

The Amazon Resource Name (ARN) of the IAM role used when creating this state machine. (The IAM role maintains security by granting Step Functions access to Amazon Web Services resources.)

Returns:

  • (String)


1324
1325
1326
1327
1328
1329
1330
1331
1332
1333
1334
1335
1336
1337
1338
1339
1340
1341
# File 'lib/aws-sdk-states/types.rb', line 1324

class DescribeStateMachineOutput < Struct.new(
  :state_machine_arn,
  :name,
  :status,
  :definition,
  :role_arn,
  :type,
  :creation_date,
  :logging_configuration,
  :tracing_configuration,
  :label,
  :revision_id,
  :description,
  :encryption_configuration,
  :variable_references)
  SENSITIVE = [:definition, :description, :variable_references]
  include Aws::Structure
end

#state_machine_arnString

The Amazon Resource Name (ARN) that identifies the state machine.

If you specified a state machine version ARN in your request, the API returns the version ARN. The version ARN is a combination of state machine ARN and the version number separated by a colon (:). For example, stateMachineARN:1.

Returns:

  • (String)


1324
1325
1326
1327
1328
1329
1330
1331
1332
1333
1334
1335
1336
1337
1338
1339
1340
1341
# File 'lib/aws-sdk-states/types.rb', line 1324

class DescribeStateMachineOutput < Struct.new(
  :state_machine_arn,
  :name,
  :status,
  :definition,
  :role_arn,
  :type,
  :creation_date,
  :logging_configuration,
  :tracing_configuration,
  :label,
  :revision_id,
  :description,
  :encryption_configuration,
  :variable_references)
  SENSITIVE = [:definition, :description, :variable_references]
  include Aws::Structure
end

#statusString

The current status of the state machine.

Returns:

  • (String)


1324
1325
1326
1327
1328
1329
1330
1331
1332
1333
1334
1335
1336
1337
1338
1339
1340
1341
# File 'lib/aws-sdk-states/types.rb', line 1324

class DescribeStateMachineOutput < Struct.new(
  :state_machine_arn,
  :name,
  :status,
  :definition,
  :role_arn,
  :type,
  :creation_date,
  :logging_configuration,
  :tracing_configuration,
  :label,
  :revision_id,
  :description,
  :encryption_configuration,
  :variable_references)
  SENSITIVE = [:definition, :description, :variable_references]
  include Aws::Structure
end

#tracing_configurationTypes::TracingConfiguration

Selects whether X-Ray tracing is enabled.



1324
1325
1326
1327
1328
1329
1330
1331
1332
1333
1334
1335
1336
1337
1338
1339
1340
1341
# File 'lib/aws-sdk-states/types.rb', line 1324

class DescribeStateMachineOutput < Struct.new(
  :state_machine_arn,
  :name,
  :status,
  :definition,
  :role_arn,
  :type,
  :creation_date,
  :logging_configuration,
  :tracing_configuration,
  :label,
  :revision_id,
  :description,
  :encryption_configuration,
  :variable_references)
  SENSITIVE = [:definition, :description, :variable_references]
  include Aws::Structure
end

#typeString

The type of the state machine (STANDARD or EXPRESS).

Returns:

  • (String)


1324
1325
1326
1327
1328
1329
1330
1331
1332
1333
1334
1335
1336
1337
1338
1339
1340
1341
# File 'lib/aws-sdk-states/types.rb', line 1324

class DescribeStateMachineOutput < Struct.new(
  :state_machine_arn,
  :name,
  :status,
  :definition,
  :role_arn,
  :type,
  :creation_date,
  :logging_configuration,
  :tracing_configuration,
  :label,
  :revision_id,
  :description,
  :encryption_configuration,
  :variable_references)
  SENSITIVE = [:definition, :description, :variable_references]
  include Aws::Structure
end

#variable_referencesHash<String,Array<String>>

A map of state name to a list of variables referenced by that state. States that do not use variable references will not be shown in the response.

Returns:

  • (Hash<String,Array<String>>)


1324
1325
1326
1327
1328
1329
1330
1331
1332
1333
1334
1335
1336
1337
1338
1339
1340
1341
# File 'lib/aws-sdk-states/types.rb', line 1324

class DescribeStateMachineOutput < Struct.new(
  :state_machine_arn,
  :name,
  :status,
  :definition,
  :role_arn,
  :type,
  :creation_date,
  :logging_configuration,
  :tracing_configuration,
  :label,
  :revision_id,
  :description,
  :encryption_configuration,
  :variable_references)
  SENSITIVE = [:definition, :description, :variable_references]
  include Aws::Structure
end