Class: Aws::States::Types::GetExecutionHistoryInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::States::Types::GetExecutionHistoryInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-states/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#execution_arn ⇒ String
The Amazon Resource Name (ARN) of the execution.
-
#include_execution_data ⇒ Boolean
You can select whether execution data (input or output of a history event) is returned.
-
#max_results ⇒ Integer
The maximum number of results that are returned per call.
-
#next_token ⇒ String
If
nextTokenis returned, there are more results available. -
#reverse_order ⇒ Boolean
Lists events in descending order of their
timeStamp.
Instance Attribute Details
#execution_arn ⇒ String
The Amazon Resource Name (ARN) of the execution.
1805 1806 1807 1808 1809 1810 1811 1812 1813 |
# File 'lib/aws-sdk-states/types.rb', line 1805 class GetExecutionHistoryInput < Struct.new( :execution_arn, :max_results, :reverse_order, :next_token, :include_execution_data) SENSITIVE = [] include Aws::Structure end |
#include_execution_data ⇒ Boolean
You can select whether execution data (input or output of a history
event) is returned. The default is true.
1805 1806 1807 1808 1809 1810 1811 1812 1813 |
# File 'lib/aws-sdk-states/types.rb', line 1805 class GetExecutionHistoryInput < Struct.new( :execution_arn, :max_results, :reverse_order, :next_token, :include_execution_data) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results that are returned per call. You can
use nextToken to obtain further pages of results. The default is
100 and the maximum allowed page size is 1000. A value of 0 uses the
default.
This is only an upper limit. The actual number of results returned per call might be fewer than the specified maximum.
1805 1806 1807 1808 1809 1810 1811 1812 1813 |
# File 'lib/aws-sdk-states/types.rb', line 1805 class GetExecutionHistoryInput < Struct.new( :execution_arn, :max_results, :reverse_order, :next_token, :include_execution_data) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If nextToken is returned, there are more results available. The
value of nextToken is a unique pagination token for each page.
Make the call again using the returned token to retrieve the next
page. Keep all other arguments unchanged. Each pagination token
expires after 24 hours. Using an expired pagination token will
return an HTTP 400 InvalidToken error.
1805 1806 1807 1808 1809 1810 1811 1812 1813 |
# File 'lib/aws-sdk-states/types.rb', line 1805 class GetExecutionHistoryInput < Struct.new( :execution_arn, :max_results, :reverse_order, :next_token, :include_execution_data) SENSITIVE = [] include Aws::Structure end |
#reverse_order ⇒ Boolean
Lists events in descending order of their timeStamp.
1805 1806 1807 1808 1809 1810 1811 1812 1813 |
# File 'lib/aws-sdk-states/types.rb', line 1805 class GetExecutionHistoryInput < Struct.new( :execution_arn, :max_results, :reverse_order, :next_token, :include_execution_data) SENSITIVE = [] include Aws::Structure end |