Class: Aws::States::Types::InspectionErrorDetails

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-states/types.rb

Overview

An object containing data about a handled exception in the tested state.

Constant Summary collapse

SENSITIVE =
[:catch_index, :retry_index, :retry_backoff_interval_seconds]

Instance Attribute Summary collapse

Instance Attribute Details

#catch_indexInteger

The array index of the Catch which handled the exception.



2313
2314
2315
2316
2317
2318
2319
# File 'lib/aws-sdk-states/types.rb', line 2313

class InspectionErrorDetails < Struct.new(
  :catch_index,
  :retry_index,
  :retry_backoff_interval_seconds)
  SENSITIVE = [:catch_index, :retry_index, :retry_backoff_interval_seconds]
  include Aws::Structure
end

#retry_backoff_interval_secondsInteger

The duration in seconds of the backoff for a retry on a failed state invocation.



2313
2314
2315
2316
2317
2318
2319
# File 'lib/aws-sdk-states/types.rb', line 2313

class InspectionErrorDetails < Struct.new(
  :catch_index,
  :retry_index,
  :retry_backoff_interval_seconds)
  SENSITIVE = [:catch_index, :retry_index, :retry_backoff_interval_seconds]
  include Aws::Structure
end

#retry_indexInteger

The array index of the Retry which handled the exception.



2313
2314
2315
2316
2317
2318
2319
# File 'lib/aws-sdk-states/types.rb', line 2313

class InspectionErrorDetails < Struct.new(
  :catch_index,
  :retry_index,
  :retry_backoff_interval_seconds)
  SENSITIVE = [:catch_index, :retry_index, :retry_backoff_interval_seconds]
  include Aws::Structure
end