Class: Aws::States::Types::ListActivitiesOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::States::Types::ListActivitiesOutput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-states/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#activities ⇒ Array<Types::ActivityListItem>
The list of activities.
-
#next_token ⇒ String
If
nextTokenis returned, there are more results available.
Instance Attribute Details
#activities ⇒ Array<Types::ActivityListItem>
The list of activities.
2677 2678 2679 2680 2681 2682 |
# File 'lib/aws-sdk-states/types.rb', line 2677 class ListActivitiesOutput < Struct.new( :activities, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If nextToken is returned, there are more results available. The value of nextToken is a unique pagination token for each page. Make the call again using the returned token to retrieve the next page. Keep all other arguments unchanged. Each pagination token expires after 24 hours. Using an expired pagination token will return an *HTTP 400 InvalidToken* error.
2677 2678 2679 2680 2681 2682 |
# File 'lib/aws-sdk-states/types.rb', line 2677 class ListActivitiesOutput < Struct.new( :activities, :next_token) SENSITIVE = [] include Aws::Structure end |