Class: Aws::States::Types::ListExecutionsOutput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-states/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#executionsArray<Types::ExecutionListItem>

The list of matching executions.

Returns:



2793
2794
2795
2796
2797
2798
# File 'lib/aws-sdk-states/types.rb', line 2793

class ListExecutionsOutput < Struct.new(
  :executions,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

If nextToken is returned, there are more results available. The value of nextToken is a unique pagination token for each page. Make the call again using the returned token to retrieve the next page. Keep all other arguments unchanged. Each pagination token expires after 24 hours. Using an expired pagination token will return an HTTP 400 InvalidToken error.

Returns:

  • (String)


2793
2794
2795
2796
2797
2798
# File 'lib/aws-sdk-states/types.rb', line 2793

class ListExecutionsOutput < Struct.new(
  :executions,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end