Class: Aws::States::Types::ListStateMachineAliasesOutput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-states/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

If nextToken is returned, there are more results available. The value of nextToken is a unique pagination token for each page. Make the call again using the returned token to retrieve the next page. Keep all other arguments unchanged. Each pagination token expires after 24 hours. Using an expired pagination token will return an HTTP 400 InvalidToken error.

Returns:

  • (String)


2904
2905
2906
2907
2908
2909
# File 'lib/aws-sdk-states/types.rb', line 2904

class ListStateMachineAliasesOutput < Struct.new(
  :state_machine_aliases,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#state_machine_aliasesArray<Types::StateMachineAliasListItem>

Aliases for the state machine.



2904
2905
2906
2907
2908
2909
# File 'lib/aws-sdk-states/types.rb', line 2904

class ListStateMachineAliasesOutput < Struct.new(
  :state_machine_aliases,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end