Class: Aws::States::Types::ListStateMachineVersionsInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::States::Types::ListStateMachineVersionsInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-states/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum number of results that are returned per call.
-
#next_token ⇒ String
If
nextTokenis returned, there are more results available. -
#state_machine_arn ⇒ String
The Amazon Resource Name (ARN) of the state machine.
Instance Attribute Details
#max_results ⇒ Integer
The maximum number of results that are returned per call. You can
use nextToken to obtain further pages of results. The default is
100 and the maximum allowed page size is 1000. A value of 0 uses the
default.
This is only an upper limit. The actual number of results returned per call might be fewer than the specified maximum.
2936 2937 2938 2939 2940 2941 2942 |
# File 'lib/aws-sdk-states/types.rb', line 2936 class ListStateMachineVersionsInput < Struct.new( :state_machine_arn, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If nextToken is returned, there are more results available. The
value of nextToken is a unique pagination token for each page.
Make the call again using the returned token to retrieve the next
page. Keep all other arguments unchanged. Each pagination token
expires after 24 hours. Using an expired pagination token will
return an HTTP 400 InvalidToken error.
2936 2937 2938 2939 2940 2941 2942 |
# File 'lib/aws-sdk-states/types.rb', line 2936 class ListStateMachineVersionsInput < Struct.new( :state_machine_arn, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#state_machine_arn ⇒ String
The Amazon Resource Name (ARN) of the state machine.
2936 2937 2938 2939 2940 2941 2942 |
# File 'lib/aws-sdk-states/types.rb', line 2936 class ListStateMachineVersionsInput < Struct.new( :state_machine_arn, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |