Class: Aws::States::Types::GetActivityTaskInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::States::Types::GetActivityTaskInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-states/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#activity_arn ⇒ String
The Amazon Resource Name (ARN) of the activity to retrieve tasks from (assigned when you create the task using CreateActivity.).
-
#worker_name ⇒ String
You can provide an arbitrary name in order to identify the worker that the task is assigned to.
Instance Attribute Details
#activity_arn ⇒ String
The Amazon Resource Name (ARN) of the activity to retrieve tasks from (assigned when you create the task using CreateActivity.)
1742 1743 1744 1745 1746 1747 |
# File 'lib/aws-sdk-states/types.rb', line 1742 class GetActivityTaskInput < Struct.new( :activity_arn, :worker_name) SENSITIVE = [] include Aws::Structure end |
#worker_name ⇒ String
You can provide an arbitrary name in order to identify the worker that the task is assigned to. This name is used when it is logged in the execution history.
1742 1743 1744 1745 1746 1747 |
# File 'lib/aws-sdk-states/types.rb', line 1742 class GetActivityTaskInput < Struct.new( :activity_arn, :worker_name) SENSITIVE = [] include Aws::Structure end |