Class: Aws::States::Types::HistoryEventExecutionDataDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::States::Types::HistoryEventExecutionDataDetails
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-states/types.rb
Overview
Provides details about input or output in an execution history event.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#truncated ⇒ Boolean
Indicates whether input or output was truncated in the response.
Instance Attribute Details
#truncated ⇒ Boolean
Indicates whether input or output was truncated in the response.
Always false for API calls. In CloudWatch logs, the value will be
true if the data is truncated due to size limits.
2077 2078 2079 2080 2081 |
# File 'lib/aws-sdk-states/types.rb', line 2077 class HistoryEventExecutionDataDetails < Struct.new( :truncated) SENSITIVE = [] include Aws::Structure end |