Class: Aws::States::Types::ListExecutionsOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::States::Types::ListExecutionsOutput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-states/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#executions ⇒ Array<Types::ExecutionListItem>
The list of matching executions.
-
#next_token ⇒ String
If
nextTokenis returned, there are more results available.
Instance Attribute Details
#executions ⇒ Array<Types::ExecutionListItem>
The list of matching executions.
2793 2794 2795 2796 2797 2798 |
# File 'lib/aws-sdk-states/types.rb', line 2793 class ListExecutionsOutput < Struct.new( :executions, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If nextToken is returned, there are more results available. The
value of nextToken is a unique pagination token for each page.
Make the call again using the returned token to retrieve the next
page. Keep all other arguments unchanged. Each pagination token
expires after 24 hours. Using an expired pagination token will
return an HTTP 400 InvalidToken error.
2793 2794 2795 2796 2797 2798 |
# File 'lib/aws-sdk-states/types.rb', line 2793 class ListExecutionsOutput < Struct.new( :executions, :next_token) SENSITIVE = [] include Aws::Structure end |