Class: Aws::States::Types::ListMapRunsOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::States::Types::ListMapRunsOutput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-states/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#map_runs ⇒ Array<Types::MapRunListItem>
An array that lists information related to a Map Run, such as the Amazon Resource Name (ARN) of the Map Run and the ARN of the state machine that started the Map Run.
-
#next_token ⇒ String
If
nextTokenis returned, there are more results available.
Instance Attribute Details
#map_runs ⇒ Array<Types::MapRunListItem>
An array that lists information related to a Map Run, such as the Amazon Resource Name (ARN) of the Map Run and the ARN of the state machine that started the Map Run.
2845 2846 2847 2848 2849 2850 |
# File 'lib/aws-sdk-states/types.rb', line 2845 class ListMapRunsOutput < Struct.new( :map_runs, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If nextToken is returned, there are more results available. The
value of nextToken is a unique pagination token for each page.
Make the call again using the returned token to retrieve the next
page. Keep all other arguments unchanged. Each pagination token
expires after 24 hours. Using an expired pagination token will
return an HTTP 400 InvalidToken error.
2845 2846 2847 2848 2849 2850 |
# File 'lib/aws-sdk-states/types.rb', line 2845 class ListMapRunsOutput < Struct.new( :map_runs, :next_token) SENSITIVE = [] include Aws::Structure end |