Class: Aws::States::Types::ListStateMachineAliasesOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::States::Types::ListStateMachineAliasesOutput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-states/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
If
nextTokenis returned, there are more results available. -
#state_machine_aliases ⇒ Array<Types::StateMachineAliasListItem>
Aliases for the state machine.
Instance Attribute Details
#next_token ⇒ String
If nextToken is returned, there are more results available. The
value of nextToken is a unique pagination token for each page.
Make the call again using the returned token to retrieve the next
page. Keep all other arguments unchanged. Each pagination token
expires after 24 hours. Using an expired pagination token will
return an HTTP 400 InvalidToken error.
2904 2905 2906 2907 2908 2909 |
# File 'lib/aws-sdk-states/types.rb', line 2904 class ListStateMachineAliasesOutput < Struct.new( :state_machine_aliases, :next_token) SENSITIVE = [] include Aws::Structure end |
#state_machine_aliases ⇒ Array<Types::StateMachineAliasListItem>
Aliases for the state machine.
2904 2905 2906 2907 2908 2909 |
# File 'lib/aws-sdk-states/types.rb', line 2904 class ListStateMachineAliasesOutput < Struct.new( :state_machine_aliases, :next_token) SENSITIVE = [] include Aws::Structure end |