Class: Aws::States::Types::ListStateMachinesOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::States::Types::ListStateMachinesOutput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-states/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
If
nextTokenis returned, there are more results available. - #state_machines ⇒ Array<Types::StateMachineListItem>
Instance Attribute Details
#next_token ⇒ String
If nextToken is returned, there are more results available. The value of nextToken is a unique pagination token for each page. Make the call again using the returned token to retrieve the next page. Keep all other arguments unchanged. Each pagination token expires after 24 hours. Using an expired pagination token will return an *HTTP 400 InvalidToken* error.
3014 3015 3016 3017 3018 3019 |
# File 'lib/aws-sdk-states/types.rb', line 3014 class ListStateMachinesOutput < Struct.new( :state_machines, :next_token) SENSITIVE = [] include Aws::Structure end |
#state_machines ⇒ Array<Types::StateMachineListItem>
3014 3015 3016 3017 3018 3019 |
# File 'lib/aws-sdk-states/types.rb', line 3014 class ListStateMachinesOutput < Struct.new( :state_machines, :next_token) SENSITIVE = [] include Aws::Structure end |